==> wiki3_5_1.zip: wiki3_5_1/plugin/admin/AccountHandler.pm <==
###############################################################################
#
# ȾԤϥɥ
#
###############################################################################
package plugin::admin::AccountHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi = $wiki->get_CGI;
	
	$wiki->set_title("Ⱦ");
	
	if($cgi->param("changepass") ne ""){
		return $self->change_pass($wiki);
	}
	if(!defined($wiki->get_login_info)) {
		return $wiki->error("󤷤Ƥޤ");
	}
	my $id = $wiki->get_login_info($cgi)->{id};
	
	return $self->account_form($wiki,$id);
}

#==============================================================================
# Ⱦե
#==============================================================================
sub account_form {
	my $self = shift;
	my $wiki = shift;
	my $id   = shift;
	
	my $buf = "<h2>Ⱦ</h2>";
	$buf .= "<h3>ID</h3>\n";
	$buf .= "<b>".&Util::escapeHTML($id)."</b>ѹϤǤޤ\n";
	
	$buf .= "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n";
	$buf .= "  <h2>ѥɤѹ</h2>\n";
	$buf .= "  ߤΥѥɤϤƤ<br/>\n";
	$buf .= "  <input type=\"password\" name=\"pass_old\" size=\"20\"><br/><br/>\n";
	$buf .= "  ѥɤϤƤ<br/>\n";
	$buf .= "  <input type=\"password\" name=\"pass1\" size=\"20\"><br/>\n";
	$buf .= "  ǧΤᡢѥɤ⤦ϤƤ<br/>\n";
	$buf .= "  <input type=\"password\" name=\"pass2\" size=\"20\">\n";

	$buf .= "  <br><br><input type=\"submit\" name=\"changepass\" value=\"ѹ\">\n";
	$buf .= "  <input type=\"hidden\" name=\"action\" value=\"ACCOUNT\">\n";
	$buf .= "  <input type=\"hidden\" name=\"id\" value=\"".&Util::escapeHTML($id)."\">\n";
	$buf .= "</form>\n";
	
	$buf .= "[<a href=\"".$wiki->config('script_name')."?action=LOGIN\"></a>]\n";
	
	return $buf;
}

#==============================================================================
# ѥɤѹ
#==============================================================================
sub change_pass {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	my $id   = $cgi->param("id");

	my $pass_old     = $cgi->param("pass_old");
	my $pass         = $cgi->param("pass1");
	my $pass_confirm = $cgi->param("pass2");


	# ߤΥѥɤξȹ

	# ¾ͤѥɤѹƤޤȤɻߤ뤿ᡢѥɤѹ
	# ݤˤϸߤΥѥɤȹ礹ɬפ롣
	my $login = $wiki->login_check($id,crypt($pass_old,$id));
	if(defined($login)){
		my $min_length = 2;

		# ѥɤγǧ
		if ( length( $pass ) < $min_length ) {
			return $wiki->error("ѥɤϤƤޤ".
				"ʤȤ $min_length ʸʾϤƤ");
		}
		elsif ( $pass ne $pass_confirm ) {
			return $wiki->error("Ϥ줿ĤΥѥɤפޤ");
		}

		my $session = $cgi->get_session($wiki);
		$session->param("wiki_id"  ,$id);
		$session->param("wiki_type",$login->{type});
		$session->param("wiki_path",$login->{path});
		$session->flush();

		my $users = &Util::load_config_hash($wiki,$wiki->config('userdat_file'));
		my ($p,$type)  = split(/\t/,$users->{$id});
		$users->{$id} = crypt($pass,$id)."\t$type";
		&Util::save_config_hash($wiki,$wiki->config('userdat_file'),$users);
	} else {
		return $wiki->error("ߤΥѥɤ㤤ޤ");
	}
	
	return "<p>ѥɤѹޤ</p>".
	       "[<a href=\"".$wiki->config('script_name')."?action=LOGIN\">˥塼</a>]\n";
}

1;

==> wiki3_5_7dev1.zip: wiki3_5_7dev1/plugin/admin/AccountHandler.pm <==
###############################################################################
#
# ȾԤϥɥ
#
###############################################################################
package plugin::admin::AccountHandler;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi = $wiki->get_CGI;
	
	$wiki->set_title("Ⱦ");
	
	if($cgi->param("changepass") ne ""){
		return $self->change_pass($wiki);
	}
	if(!defined($wiki->get_login_info)) {
		return $wiki->error("󤷤Ƥޤ");
	}
	my $id = $wiki->get_login_info($cgi)->{id};
	
	return $self->account_form($wiki,$id);
}

#==============================================================================
# Ⱦե
#==============================================================================
sub account_form {
	my $self = shift;
	my $wiki = shift;
	my $id   = shift;
	
	my $buf = "<h2>Ⱦ</h2>";
	$buf .= "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n";
	$buf .= "  <table>\n";
	$buf .= "  <tr>\n";
	$buf .= "  <th>ID</th>\n";
	$buf .= "  <td><b>".&Util::escapeHTML($id)."</b>ѹϤǤޤ</td>\n";
	$buf .= "  </tr>\n";
	$buf .= "  <tr>\n";
	$buf .= "  <th>ߤΥѥ</th>\n";
	$buf .= "  <td><input type=\"password\" name=\"pass_old\" size=\"30\"></td>\n";
	$buf .= "  </tr>\n";
	$buf .= "  <tr>\n";
	$buf .= "  <th>ѥ</th>\n";
	$buf .= "  <td><input type=\"password\" name=\"pass1\" size=\"30\"></td>\n";
	$buf .= "  </tr>\n";
	$buf .= "  <tr>\n";
	$buf .= "  <th>ѥɡʳǧ</th>\n";
	$buf .= "  <td><input type=\"password\" name=\"pass2\" size=\"30\"></td>\n";
	$buf .= "  </tr>\n";
	$buf .= "  </table>\n";
#	$buf .= "  <div style=\"margin-top:10pt;\">\n";
	$buf .= "    <input type=\"submit\" name=\"changepass\" value=\"ѹ\">\n";
	$buf .= "    <input type=\"hidden\" name=\"action\" value=\"ACCOUNT\">\n";
	$buf .= "    <input type=\"hidden\" name=\"id\" value=\"".&Util::escapeHTML($id)."\">\n";
#	$buf .= "  </div>\n";
	$buf .= "</form>\n";
	
	return $buf;
}

#==============================================================================
# ѥɤѹ
#==============================================================================
sub change_pass {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	my $id   = $cgi->param("id");

	my $pass_old     = $cgi->param("pass_old");
	my $pass         = $cgi->param("pass1");
	my $pass_confirm = $cgi->param("pass2");


	# ߤΥѥɤξȹ

	# ¾ͤѥɤѹƤޤȤɻߤ뤿ᡢѥɤѹ
	# ݤˤϸߤΥѥɤȹ礹ɬפ롣
	my $login = $wiki->login_check($id,&Util::md5($pass_old,$id));
	if(defined($login)){
		my $min_length = 2;

		# ѥɤγǧ
		if ( length( $pass ) < $min_length ) {
			return $wiki->error("ѥɤϤƤޤ".
				"ʤȤ $min_length ʸʾϤƤ");
		}
		elsif ( $pass ne $pass_confirm ) {
			return $wiki->error("Ϥ줿ĤΥѥɤפޤ");
		}

		my $session = $cgi->get_session($wiki);
		$session->param("wiki_id"  ,$id);
		$session->param("wiki_type",$login->{type});
		$session->param("wiki_path",$login->{path});
		$session->flush();

		my $users = &Util::load_config_hash($wiki,$wiki->config('userdat_file'));
		my ($p,$type)  = split(/\t/,$users->{$id});
		$users->{$id} = &Util::md5($pass,$id)."\t$type";
		&Util::save_config_hash($wiki,$wiki->config('userdat_file'),$users);
	} else {
		return $wiki->error("ߤΥѥɤ㤤ޤ");
	}
	
	$wiki->redirectURL($wiki->config('script_name')."?action=LOGIN");
	
	#return "<p>ѥɤѹޤ</p>".
	#       "[<a href=\"".$wiki->config('script_name')."?action=LOGIN\">˥塼</a>]\n";
}

1;
